<?php
namespace Teknisa\CMP\Modules\Cadastros\Controllers;

use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification;
use Teknisa\CMP\Modules\Cadastros\Services\Cmp00500RegiaoNaoAtendidaPeloFornecedorService;

class Cmp00500RegiaoNaoAtendidaPeloFornecedor extends \Zeedhi\Framework\Controller\Report{

    protected $connection;
    protected $qr2Strategy;
    protected $stNomeRel;
    
    public function __construct(reportService $reportService, $service, $connection, $qr2Strategy ) {
        parent::__construct($reportService);    
        $this->service       = $service;
        $this->connection    = $connection;
        $this->qr2Strategy      = $qr2Strategy;
    }
    
    public function concatArray($array){
        return join('_', $array);
    }
   
    public function insertRegiao(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        $this->service->insertRegiao($row);
        $this->service->excluiFiliAtend($row);
        $this->service->incluiFilNAtend($row);
    }
    
    public function saveRegiao(DTO\Request $request, DTO\Response $response){
        $row = $request->getDataSet()->getRows()[0];
        
        $regiaoExists = false;
        
        $regiao = $this->service->findRegiao($row);
        if(!empty($regiao)){
            foreach ($regiao as $value) {
                if($value['CDREGIAO'] == $row['CDREGIAO']){
                    $regiaoExists = true;
                    break;
                }
            }
        }
        if($regiaoExists == true) {
            $erro = new Error("Operação bloqueada! A região informada já está cadastrada como não atendida!", 500);
            $response->setError($erro);
        } else {
            $verificacao = 'S';
             $response->addDataSet(new DataSet('verificacao', [$verificacao]));
        }
    }
    
    public function verificaFilialReg(DTO\Request $request, DTO\Response $response) {
        $row = $request->getDataSet()->getRows()[0];
        $filReg = $this->service->verificaFilialReg($row);
        if(!empty($filReg)){
            $erro = 1;
        }
        else {
            $erro = 0;
            $this->service->insertRegiao($row);
        }
        $response->addDataSet(new DataSet('erro', [$erro])); 
    }
    
    public function regiaoDelete(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        
        if(!empty($row)){
            foreach ($row as $value) {
                $this->service->deleteRegiao($value);
            }
        }
    }
    
    public function verificaExportacao(DTO\Request $request, DTO\Response $response) {
        $row = $request->getDataSet()->getRows()[0];
        $verifExportacao = $this->service->verificaExportacao($row);
        $msg = '';
        if(empty($verifExportacao)){
            $this->exportRegiao($row);
            $msg = "A exportação foi realizada com sucesso!";
        }
       
        $response->addDataSet(new DataSet('dados', [$msg, $verifExportacao])); 
    }
    
    public function exportRegiao($row){
        
        $row['CDFORNECEDDEST'] = is_array($row['CDFORNECEDDEST']) ? count($row['CDFORNECEDDEST']) > 0 ? self::concatArray($row['CDFORNECEDDEST']) : 'T' : 'T';
        $row['CDREGIAO']       = is_array($row['CDREGIAO'])       ? count($row['CDREGIAO'])       > 0 ? self::concatArray($row['CDREGIAO'])       : 'T' : 'T';
      
            $this->service->insertExportation($row);
    }
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        
        $this->qr2Strategy->setQr2Type($row['QR2TYPE']);
        $this->stNomeRel = $this->getReportName($row);
        $this->reportMapping[$this->stNomeRel] =
            array (
                'strategy' => $row['STRATEGY'],
                'parameterMapping' => 
                array (
                    'CDFORNECED1'   => 'P_INSCR',
                    'CDFORNECED2'  => 'L_INSCR'
                ),
            );
    }
}
